@@ -18,7 +18,10 @@ RcppExport SEXP R_partialOrder(SEXP R_x, SEXP R_h);
 //SEXP R_partialSort(SEXP R_x, SEXP R_h);
 
 // functions to be used within C++
+vec applyScaleFun(const mat& x, SEXP scaleFun);
 uvec findSmallest(const vec& x, const uword& h);
 uvec partialOrder(const vec& x, const uword& h);
+uvec seqLen(const uword& n);
+sword sign(const double& x);
 
 #endif
